@@ -69,7 +69,8 @@ ddist2 <- function(distance, control) {
         }
 
         if (!is.null(control$distmat)) {
-            if (!inherits(control$distmat, "Distmat")) stop("Invalid distance matrix in control.")
+            if (!inherits(control$distmat, "Distmat"))
+                stop("Invalid distance matrix in control.") # nocov
             # internal class, sparse or full
             i <- 1L:length(x)
             j <- if (is.null(centroids)) i else control$distmat$id_cent
@@ -90,8 +91,12 @@ ddist2 <- function(distance, control) {
 
             # dtw uses L2 by default, but in dtwclust I want dtw to use L1 by default
             # Important for multivariate series
-            if (toupper(dist_entry$names[1L]) == "DTW" && is.null(dots$dist.method))
+            if (toupper(dist_entry$names[1L]) == "DTW" &&
+                is.null(dots$dist.method) &&
+                is_multivariate(c(x, centroids)))
+            {
                 dots$dist.method <- "L1"
+            }
 
             # If the function doesn't have '...', remove invalid arguments from 'dots'
             valid_args <- names(dots)
